@@ -1,4 +1,5 @@
 import json
+import posixpath
 from collections import namedtuple
 from typing import List, Optional
 
@@ -172,6 +173,12 @@ class CrashReport:
             return None
         return result
 
+    def __repr__(self):
+        filename = ''
+        if self.filename:
+            filename = f'FILENAME:{posixpath.basename(self.filename)} '
+        return f'<CrashReport {filename}TIMESTAMP:{self.timestamp}>'
+
     def __str__(self):
         filename = ''
         if self.filename:
@@ -192,7 +199,7 @@ class CrashReport:
 
         if self.application_specific_information:
             result += click.style('Application Specific Information: ', bold=True)
-            result += self.application_specific_information
+            result += str(self.application_specific_information)
 
         result += '\n'
 
